@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -50,7 +50,7 @@ void SieveEditorGraphicalModeWidgetTest::shouldLoadScripts()
     const QString originalFile = QLatin1String(KSIEVEUI_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral(".siv");
     const QString refFile = QLatin1String(KSIEVEUI_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral("-ref.siv");
     const QString generatedFile = QLatin1String(KSIEVEUI_BINARY_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral("-generated.siv");
-    QDir().mkpath(QLatin1String(KSIEVEUI_BINARY_DATA_DIR));
+    QDir().mkpath(QStringLiteral(KSIEVEUI_BINARY_DATA_DIR));
     QString script = readSieveFile(originalFile);
     // First parsing
     bool result = false;
