@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,6 @@
 #include "sievetemplateeditdialog.h"
 #include "editor/sievetextedit.h"
 
-#include <KPIMTextEdit/PlainTextEditFindBar>
-#include <KPIMTextEdit/SlideContainer>
 #include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KLocalizedString>
@@ -24,15 +22,19 @@
 #include <QVBoxLayout>
 
 #include <editor/sievetexteditwidget.h>
-
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeechWidget>
-
+#endif
 using namespace KSieveUi;
-
+namespace
+{
+static const char mySieveTemplateEditDialogGroupName[] = "SieveTemplateEditDialog";
+}
 SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTemplate)
     : QDialog(parent)
 {
-    setWindowTitle(defaultTemplate ? i18n("Default template") : i18n("Template"));
+    setWindowTitle(defaultTemplate ? i18nc("@title:window", "Default template") : i18nc("@title:window", "Template"));
     auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = nullptr;
     if (defaultTemplate) {
@@ -62,16 +64,18 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
     hbox->addWidget(mTemplateNameEdit);
 
     vbox->addLayout(hbox);
-
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     auto textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     vbox->addWidget(textToSpeechWidget);
+#endif
 
     mTextEditWidget = new KSieveUi::SieveTextEditWidget;
     mTextEditWidget->textEdit()->setShowHelpMenu(false);
     mTextEditWidget->setReadOnly(defaultTemplate);
     vbox->addWidget(mTextEditWidget);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     connect(mTextEditWidget->textEdit(), &SieveTextEdit::say, textToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
-
+#endif
     auto shortcut = new QShortcut(this);
     shortcut->setKey(Qt::Key_F | Qt::CTRL);
     connect(shortcut, &QShortcut::activated, mTextEditWidget, &SieveTextEditWidget::slotFind);
@@ -104,13 +108,13 @@ SieveTemplateEditDialog::~SieveTemplateEditDialog()
 
 void SieveTemplateEditDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveTemplateEditDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveTemplateEditDialogGroupName);
     group.writeEntry("Size", size());
 }
 
 void SieveTemplateEditDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveTemplateEditDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveTemplateEditDialogGroupName);
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
