@@ -1,15 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MOVEIMAPFOLDERWIDGET_H
-#define MOVEIMAPFOLDERWIDGET_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <KSieveUi/AbstractMoveImapFolderWidget>
-#include <QWidget>
 class QLineEdit;
 namespace KSieveUi
 {
@@ -30,4 +28,3 @@ private:
     QLineEdit *const mLineEdit;
 };
 }
-#endif // MOVEIMAPFOLDERWIDGET_H
